Merge "[qca-nss-drv] Update headers"
diff --git a/exports/nss_gre_tunnel.h b/exports/nss_gre_tunnel.h
index fbfb831..70f7cb0 100644
--- a/exports/nss_gre_tunnel.h
+++ b/exports/nss_gre_tunnel.h
@@ -106,7 +106,7 @@
 	uint32_t crypto_idx_encrypt;	/**< Crypto index for encryption. */
 	uint32_t crypto_idx_decrypt;	/**< Crypto index for decryption. */
 	uint32_t word0;			/**< Word0 header. */
-	uint8_t iv_val[16];		/**< IV value. ??spell out IV*/
+	uint8_t iv_val[16];		/**< Initialization vector value. */
 	uint8_t ttl;			/**< Time-to-live value of the IP header. */
 };
 
@@ -116,28 +116,30 @@
  */
 struct nss_gre_tunnel_stats {
 	struct nss_cmn_node_stats node_stats;	/**< Common node statistics. */
-	uint32_t rx_malformed;		/**< Malformed packet was received. */
-	uint32_t rx_invalid_prot;	/**< Invalid protocol was received. */
-	uint32_t decap_queue_full;	/**< Decapsulation queue is full. */
-	uint32_t rx_single_rec_dgram;	/**< Single fragment was received. */
-	uint32_t rx_invalid_rec_dgram;	/**< Invalid fragment was received. */
-	uint32_t buffer_alloc_fail;	/**< Buffer memory allocation failed. */
-	uint32_t buffer_copy_fail;	/**< Buffer memory copy failed. */
-	uint32_t outflow_queue_full;	/**< Outflow queue is full. */
+	uint32_t rx_malformed;			/**< Malformed packet was received. */
+	uint32_t rx_invalid_prot;		/**< Invalid protocol was received. */
+	uint32_t decap_queue_full;		/**< Decapsulation queue is full. */
+	uint32_t rx_single_rec_dgram;		/**< Single fragment was received. */
+	uint32_t rx_invalid_rec_dgram;		/**< Invalid fragment was received. */
+	uint32_t buffer_alloc_fail;		/**< Buffer memory allocation failed. */
+	uint32_t buffer_copy_fail;		/**< Buffer memory copy failed. */
+	uint32_t outflow_queue_full;		/**< Outflow queue is full. */
 	uint32_t rx_dropped_hroom;
-			/**< Packets dropped because of insufficent headroom. */
-	uint32_t rx_cbuf_alloc_fail;	/**< Rx crypto buffer allocation failed. */
-	uint32_t rx_cenqueue_fail;	/**< Rx enqueue-to-crypto failed. */
-	uint32_t rx_decrypt_done;	/**< Rx decryption is complete. */
-	uint32_t rx_forward_enqueue_fail;
-			/**< Rx forward enqueue failed. */
-	uint32_t tx_cbuf_alloc_fail;	/**< Rx crypto buffer allocation failed. */
-	uint32_t tx_cenqueue_fail;	/**< Tx enqueue-to-crypto failed. */
+				/**< Packets dropped because of insufficent headroom. */
+	uint32_t rx_cbuf_alloc_fail;
+				/**< Rx crypto buffer allocation failed. */
+	uint32_t rx_cenqueue_fail;		/**< Rx enqueue-to-crypto failed. */
+	uint32_t rx_decrypt_done;		/**< Rx decryption is complete. */
+	uint32_t rx_forward_enqueue_fail;	/**< Rx forward enqueue failed. */
+	uint32_t tx_cbuf_alloc_fail;
+				/**< Rx crypto buffer allocation failed. */
+	uint32_t tx_cenqueue_fail;		/**< Tx enqueue-to-crypto failed. */
 	uint32_t rx_dropped_troom;
-			/**< Packets dropped because of insufficent tailroom. */
+				/**< Packets dropped because of insufficent tailroom. */
 	uint32_t tx_forward_enqueue_fail;	/**< Tx forward enqueue failed. */
 	uint32_t tx_cipher_done;		/**< Tx cipher is complete. */
-	uint32_t crypto_nosupp;			/**< Crypto no supported count error. ??not sure how to edit this; what does it mean? */
+	uint32_t crypto_nosupp;
+				/**< Error count for non-supported crypto packets. */
 };
 
 /**
@@ -145,17 +147,15 @@
  *	Data for sending and receiving GRE tunnel messages.
  */
 struct nss_gre_tunnel_msg {
-	struct nss_cmn_msg cm;		/**< Common message header. */
+	struct nss_cmn_msg cm;					/**< Common message header. */
 
 	/**
 	 * Payload of a GRE tunnel message.
 	 */
 	union {
-		struct nss_gre_tunnel_configure configure;
-				/**< Tunnel configuration data. */
-		struct nss_gre_tunnel_stats stats;
-				/**< Tunnel statistics. */
-	} msg;			/**< Message payload. ??is this comment correct? I assumed it's the message payload because the first field is the message header */
+		struct nss_gre_tunnel_configure configure;	/**< Tunnel configuration data. */
+		struct nss_gre_tunnel_stats stats;		/**< Tunnel statistics. */
+	} msg;							/**< Message payload. */
 };
 
 /**
@@ -191,9 +191,9 @@
  * sk_buff \n
  * nss_ctx_instance
  *
- * @param[in]     skb      Pointer to the data socket buffer.
- * @param[in]     if_num   Tunnel interface number.
- * @param[in,out] nss_ctx  Pointer to the NSS context.
+ * @param[in] skb      Pointer to the data socket buffer.
+ * @param[in] if_num   Tunnel interface number.
+ * @param[in] nss_ctx  Pointer to the NSS context.
  *
  * @return
  * Status of the Tx operation.
@@ -208,8 +208,8 @@
  * nss_ctx_instance \n
  * nss_gre_tunnel_msg
  *
- * @param[in,out] nss_ctx  Pointer to the NSS context.
- * @param[in]     msg      Pointer to the message data.
+ * @param[in] nss_ctx  Pointer to the NSS context.
+ * @param[in] msg      Pointer to the message data.
  *
  * @return
  * Status of the Tx operation.
@@ -224,8 +224,8 @@
  * nss_ctx_instance \n
  * nss_gre_tunnel_msg
  *
- * @param[in,out] nss_ctx  Pointer to the NSS context.
- * @param[in,out] msg      Pointer to the message data.
+ * @param[in] nss_ctx  Pointer to the NSS context.
+ * @param[in] msg      Pointer to the message data.
  *
  * @return
  * Status of the Tx operation.
@@ -239,12 +239,12 @@
  * @datatypes
  * nss_gre_tunnel_msg
  *
- * @param[in,out] ngtm      Pointer to the tunnel message.
- * @param[in]     if_num    Tunnel interface number.
- * @param[in]     type      Type of message.
- * @param[in]     len       Size of the payload.
- * @param[in]     cb        Pointer to the message callback.
- * @param[in]     app_data  Pointer to the application context of the message.
+ * @param[in] ngtm      Pointer to the tunnel message.
+ * @param[in] if_num    Tunnel interface number.
+ * @param[in] type      Type of message.
+ * @param[in] len       Size of the payload.
+ * @param[in] cb        Pointer to the message callback.
+ * @param[in] app_data  Pointer to the application context of the message.
  *
  * @return
  * None.
diff --git a/exports/nss_dynamic_interface.h b/exports/nss_dynamic_interface.h
index d07a5e5..3ceafb5 100644
--- a/exports/nss_dynamic_interface.h
+++ b/exports/nss_dynamic_interface.h
@@ -70,25 +70,25 @@
 
 /**
  * nss_dynamic_interface_alloc_node_msg
  *	Message information for aynamic interface allocation node.
  */
 struct nss_dynamic_interface_alloc_node_msg {
 	enum nss_dynamic_interface_type type;	/**< Type of dynamic interface. */
 
 	/*
-	 * Response
+	 * Response.
 	 */
-	int if_num;				/**< Interface number. */
+	int if_num;				/**< Dynamic interface number. */
 };
 
 /**
  * nss_dynamic_interface_dealloc_node_msg
  *	Message information for daynamic interface deallocation node.
  */
 struct nss_dynamic_interface_dealloc_node_msg {
 	enum nss_dynamic_interface_type type;
 			/**< Type of dynamic interface. */
-	int if_num;	/**< Interface number.??need more info */
+	int if_num;	/**< Dynamic interface number. */
 };
 
 /**
@@ -106,7 +106,7 @@
 				/**< Allocates a dynamic node. */
 		struct nss_dynamic_interface_dealloc_node_msg dealloc_node;
 				/**< Deallocates a dynamic node. */
-	} msg;			/**< Message payload. ??is this comment correct? I assumed it's the message payload because the first field is the message header */
+	} msg;			/**< Message payload. */
 };
 
 /**
@@ -114,10 +114,11 @@
  *	Private data information for the dynamic interface.
  */
 struct nss_dynamic_interface_pvt {
-	struct semaphore sem;		/**< Semaphore ??need more info. */
-	struct completion complete;	/**< Completion ??need more info. */
+	struct semaphore sem;		/**< Semaphore for sending one message at a time. */
+	struct completion complete;	/**< Blocks the thread until an acknowledgment is received. */
 	int current_if_num;		/**< Current interface number. */
-	enum nss_cmn_response response;	/**< Message ??need more info. */
+	enum nss_cmn_response response;
+		/**< Holds the return message from NSS firmware. */
 	nss_dynamic_interface_assigned type[NSS_MAX_DYNAMIC_INTERFACES];
 					/**< Array of assigned interface types. */
 };
@@ -171,7 +172,7 @@
  * @param[in] if_num  Dynamic interface number.
  *
  * @return
- * Dynamic interface type ??
+ * Type of dynamic interface per the dynamic interface number.
  */
 extern enum nss_dynamic_interface_type nss_dynamic_interface_get_type(int if_num);
 
@@ -183,11 +184,11 @@
  * nss_ctx_instance \n
  * nss_dynamic_interface_msg
  *
- * @param[in,out] nss_ctx  Pointer to the NSS context.
- * @param[in]     msg      Pointer to the message data.
+ * @param[in] nss_ctx  Pointer to the NSS context.
+ * @param[in] msg      Pointer to the message data.
  *
  * @return
- * Status of the Tx operation.
+ * Status of the transmit operation.
  */
 extern nss_tx_status_t nss_dynamic_interface_tx(struct nss_ctx_instance *nss_ctx, struct nss_dynamic_interface_msg *msg);
 
@@ -209,13 +210,12 @@
  * @datatypes
  * nss_dynamic_interface_msg
  *
- * @param[in,out] ndm       Pointer to the dynamic interface message.
- * @param[in]     if_num    Dynamic interface number.
- * @param[in]     type      Type of message.
- * @param[in]     len       Size of the payload.
- * @param[in]     cb        Pointer to the message callback.
- * @param[in]     app_data  Pointer to the application context that is passed to
-                        the callback function.
+ * @param[in] ndm       Pointer to the dynamic interface message.
+ * @param[in] if_num    Dynamic interface number.
+ * @param[in] type      Type of message.
+ * @param[in] len       Size of the payload.
+ * @param[in] cb        Pointer to the message callback.
+ * @param[in] app_data  Pointer to the application context that is passed to the callback function.
  *
  * @return
  * None.
@@ -70,25 +70,25 @@
 /**
  * nss_dynamic_interface_alloc_node_msg
- *	Message information for aynamic interface allocation node.
+ *	Message information for a dynamic interface allocation node.
  */
 struct nss_dynamic_interface_alloc_node_msg {
@@ -70,25 +70,25 @@
 /**
  * nss_dynamic_interface_dealloc_node_msg
- *	Message information for daynamic interface deallocation node.
+ *	Message information for dynamic interface deallocation node.
  */
 struct nss_dynamic_interface_dealloc_node_msg {